@@ -216,10 +216,9 @@ void* microfeed_store_replace_impl(MicrofeedStore* store, void* data) {
 		        	(store->size - index) * sizeof(void*));
 		}
 		store->size++;
-	} if (store->weak_references) {
-		microfeed_weak_reference_unref((MicrofeedWeakReference*)existing);
 	}
 	if (store->weak_references) {
+		microfeed_weak_reference_unref((MicrofeedWeakReference*)existing);
 		store->data[index] = microfeed_object_get_weak_reference_generic(MICROFEED_OBJECT(data));
 	} else {
 		store->data[index] = data;
@@ -303,16 +302,11 @@ MicrofeedStoreIterator* microfeed_store_iterate(MicrofeedStore* store, const voi
 		} else {
 			iterator->index = store->size;
 		}
-	} else {
-		iterator->index = 0;
 	}
 	if (store->iterators) {
 		store->iterators->previous = iterator;
 		iterator->next = store->iterators;
-	} else {
-		iterator->next = NULL;
 	}
-	iterator->previous = NULL;
 	store->iterators = iterator;
 	
 	return iterator;
@@ -453,7 +447,7 @@ static int get_index(MicrofeedStore* store, const void* key, unsigned int* index
 				remove_index(store, store->size - 1);
 				retval = get_index(store, key, index_return, data_return);
 			} else if ((result = store->compare_keys(key, store->get_key(object))) == 0) {
-				*index_return = store->size -1;
+				*index_return = store->size - 1;
 				*data_return = object;
 				retval = 1;
 			} else if (microfeed_object_unref_generic(object), result > 0) {
@@ -510,7 +504,7 @@ static int get_index(MicrofeedStore* store, const void* key, unsigned int* index
 			} else if (store->size == 1) {
 				*index_return = 1;
 			} else if ((result = store->compare_keys(key, store->get_key(store->data[store->size - 1]))) == 0) {
-				*index_return = store->size -1;
+				*index_return = store->size - 1;
 				*data_return = store->data[store->size - 1];
 				retval = 1;
 			} else if (result > 0) {
@@ -562,7 +556,7 @@ static void remove_index(MicrofeedStore* store, unsigned int index) {
 	}
 
 	for (iterator = store->iterators; iterator; iterator = iterator->next) {
-		if (iterator->index <= index) {
+		if (iterator->index >= index) {
 			iterator->index--;
 		}
 	}
