@@ -543,7 +543,7 @@ void microfeed_feed_republish(MicrofeedFeed* feed, const char* start_uid, const
 
 	end_uid_size = (end_uid ? strlen(end_uid) + 1 : 0);
 	count = 0;
-	for (iterator = microfeed_database_index_iterate(feed->uid_index, start_uid, (start_uid ? strlen(start_uid) + 1 : 0), 0);
+	for (iterator = microfeed_database_index_iterate(feed->uid_index, start_uid, (start_uid ? strlen(start_uid) + 1 : 0), (!start_uid && !end_uid ? 1 : 0));
 	     microfeed_database_iterator_get(iterator, &data, &data_size);
 	     microfeed_database_iterator_next(iterator)) {
 		if (feed->master_feed) {
