@@ -510,7 +510,7 @@ static char* generate_oauth_signature(const char* method, const char* url, const
 	char* base64;
 	char* escaped;
 	
-	parameters_store = microfeed_store_new_sorted((MicrofeedStoreCompareKeysFunction)strcmp, microfeed_store_get_key_direct);
+	parameters_store = microfeed_store_new_sorted_data((MicrofeedStoreCompareKeysFunction)strcmp, microfeed_store_get_key_direct);
 	if ((s = strchr(url, '?'))) {
 		copy = strndup(url, s - url);
 		escaped_url = microfeed_util_string_percent_encoding_escape(copy);
