@@ -170,7 +170,7 @@ MicrofeedPublisher* microfeed_publisher_new(MicrofeedProvider* provider, const c
 		publisher->object_path = microfeed_util_string_concatenate(MICROFEED_DBUS_OBJECT_PATH_PREFIX_PUBLISHER, publisher->identifier, NULL);
 		publisher->data_directory = microfeed_util_string_concatenate(directory, "/", publisher_identifier, "/data/", NULL);
 		*separator = MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR;
-		publisher->provider = provider;
+		publisher->provider = microfeed_object_ref(provider, MicrofeedProvider);
 		publisher->callbacks = *callbacks;
 		publisher->user_data = user_data;
 
@@ -207,6 +207,7 @@ static void free_function(MicrofeedPublisher* publisher) {
 	microfeed_assert(microfeed_store_get_size(publisher->subscribers) == 0);
 	microfeed_assert(microfeed_store_get_size(publisher->store_data_requests) == 0);
 
+	microfeed_object_unref(publisher->provider, MicrofeedProvider);
 	free(publisher->identifier);
 	free(publisher->object_path);
 	free(publisher->data_directory);
